#! /usr/env/python

"""
AppShell provides a GUI application framework.

This is a streamlined adaptation of GuiAppD.py, originally
created by Doug Hellmann (doughellmann@mindspring.com).

"""

from Tkinter import *
import Pmw
import sys, string
import ProgressBar
import Image, ImageTk

Image._initialized = 1



class AppShell(Pmw.MegaWidget):        
    appversion      = '0.1'
    appname         = 'GPS Bada'
    copyright       = 'Copylift'
    contactname     = 'Kim Young Suk '
    contactphone    = 'Mobile 016-897-7635'
    contactemail    = 'n-bada@mail.skhu.ac.kr'
          
    frameWidth      = 1024
    frameHeight     = 780
    padx            = 5
    pady            = 5
    usecommandarea  = 0
    balloonhelp     = 1
    
    busyCursor = 'watch'
    
    def __init__(self, **kw):
        optiondefs = (
            ('padx',           1,                   Pmw.INITOPT),
            ('pady',           1,                   Pmw.INITOPT),  
            ('framewidth',     1,                   Pmw.INITOPT),
            ('frameheight',    1,                   Pmw.INITOPT),
            ('usecommandarea', self.usecommandarea, Pmw.INITOPT))
        self.defineoptions(kw, optiondefs)
        
        self.root = Tk()
        self.initializeTk(self.root)
        Pmw.initialise(self.root)
        self.root.title(self.appname)
        self.root.geometry('%dx%d' % (self.frameWidth, self.frameHeight))
        #self.root.geometry(0x)
        # Initialize the base class
        Pmw.MegaWidget.__init__(self, parent=self.root)
        
        # initialize the application
        self.appInit()
        
        # create the interface
        self.__createInterface()
        
        # create a table to hold the cursors for
        # widgets which get changed when we go busy
        self.preBusyCursors = None
        
        # pack the container and set focus
        # to ourselves
        self._hull.pack(side=TOP, fill=BOTH, expand=YES)
        self.focus_set()

        # initialize our options
        self.initialiseoptions(AppShell)
        
    def appInit(self):
        # Called before interface is created (should be overridden).
        pass
        
    def initializeTk(self, root):
        # Initialize platform-specific options
        if sys.platform == 'mac':
            self.__initializeTk_mac(root)
        elif sys.platform == 'win32':
            self.__initializeTk_win32(root)
        else:
            self.__initializeTk_unix(root)

    def __initializeTk_colors_common(self, root):
        root.option_add('*background', 'grey')
        root.option_add('*foreground', 'black')
        root.option_add('*EntryField.Entry.background', 'white')
        root.option_add('*Entry.background', 'white')        
        root.option_add('*MessageBar.Entry.background', 'gray85')
        root.option_add('*Listbox*background', 'white')
        root.option_add('*Listbox*selectBackground', 'dark slate blue')
        root.option_add('*Listbox*selectForeground', 'white')
                        
    def __initializeTk_win32(self, root):
        self.__initializeTk_colors_common(root)
        root.option_add('*Font', 'Verdana 10 ')
        root.option_add('*EntryField.Entry.Font', 'Courier 10')
        root.option_add('*Listbox*Font', 'Courier 10')
        
    def __initializeTk_mac(self, root):
        self.__initializeTk_colors_common(root)
        
    def __initializeTk_unix(self, root):
        self.__initializeTk_colors_common(root)
    
    def busyStart(self, newcursor=None):
        if not newcursor:
            newcursor = self.busyCursor
        newPreBusyCursors = {}
        for component in self.busyWidgets:
            newPreBusyCursors[component] = component['cursor']
            component.configure(cursor=newcursor)
            component.update_idletasks()
        self.preBusyCursors = (newPreBusyCursors, self.preBusyCursors)
        
    def busyEnd(self):
        if not self.preBusyCursors:
            return
        oldPreBusyCursors = self.preBusyCursors[0]
        self.preBusyCursors = self.preBusyCursors[1]
        for component in self.busyWidgets:
            try:
                component.configure(cursor=oldPreBusyCursors[component])
            except KeyError:
                pass
            component.update_idletasks()
              
    def __createAboutBox(self):
        Pmw.aboutversion(self.appversion)
        Pmw.aboutcopyright(self.copyright)
        Pmw.aboutcontact(
          'For more information, contact:\n %s\n Phone: %s\n Email: %s' %\
                      (self.contactname, self.contactphone, 
                       self.contactemail))
        self.about = Pmw.AboutDialog(self._hull, 
                                     applicationname=self.appname)
        self.about.withdraw()
        return None
    def __createSetting(self):
        self.setting = Pmw.Dialog(self._hull,
	     buttons = ('Ok', 'Apply', 'Cancel', 'Help'),
	     defaultbutton = 'OK',
	     title = 'My dialog')
	#Label(self.setting.interior(), text='A group with \a Lablegag')
	self.setting.withdraw()

	return None

    def showAbout(self):
        # Create the dialog to display about and contact information.
        self.about.show()
        self.about.focus_set()
    def settingAbout(self):
    	self.setting.show()
	self.setting.focus_set()
	
    def toggleBalloon(self):
	if self.toggleBalloonVar.get():
            self.__balloon.configure(state = 'both')
	else:
            self.__balloon.configure(state = 'status')

    def __createMenuBar(self):
        self.menuBar = self.createcomponent('menubar', (), None,
                                            Pmw.MenuBar,
                                            (self._hull,),
                                            hull_relief=RAISED,
                                            hull_borderwidth=1,
                                            balloon=self.balloon())

        self.menuBar.pack(fill=X)
        self.menuBar.addmenu('Help', 'About %s' % self.appname, side='right')
        self.menuBar.addmenu('File', 'File commands and Quit')
	self.menuBar.addmenu('Setting', 'Setting Program')


    def createMenuBar(self):
        self.menuBar.addmenuitem('Help', 'command',
                                 'Get information on application', 
                                 label='About...', command=self.showAbout)
        self.toggleBalloonVar = IntVar()
        self.toggleBalloonVar.set(1)
        self.menuBar.addmenuitem('Help', 'checkbutton',
                                 'Toggle balloon help',
                                 label='Balloon help',
                                 variable = self.toggleBalloonVar,
                                 command=self.toggleBalloon)
				 

				 #setting About.....
	self.menuBar.addmenuitem('Setting', 'command', 'Setting Progrma',
				label='program Setting',
				 command=self.settingAbout)				

        self.menuBar.addmenuitem('File', 'command', 'Quit this application',
                                label='Quit',
                                command=self.quit)
                                        
    def __createBalloon(self):
        # Create the balloon help manager for the frame.
        # Create the manager for the balloon help
        self.__balloon = self.createcomponent('balloon', (), None,
                                              Pmw.Balloon, (self._hull,))

    def balloon(self):
        return self.__balloon

    def __createDataArea(self):
        # Create data area where data entry widgets are placed.
        self.dataArea = self.createcomponent('dataarea',
                                             (), None,
                                             Frame, (self._hull,), 
                                             relief=GROOVE, 
                                             bd=1)
        self.dataArea.pack(side=TOP, fill=BOTH, expand=YES,
                           padx=self['padx'], pady=self['pady'])
       #Create side butten. kim young suk       #Create side butten. kim young suk  
    def __createSideButten(self):
    	self.sideButten	= self.createcomponent('sidebutten',
						(),None,
						Frame, (self._hull,),
						relief=GROOVE,
						bd=1)
	self.sideButten.pack(side=RIGHT, fill=BOTH, expand=YES,
			     padx=self['padx'], pady=self['pady'])
			    

    def __createCommandArea(self):
        # Create a command area for application-wide buttons.
        self.__commandFrame = self.createcomponent('commandframe', (), None,
                                                   Frame,
                                                   (self._hull,),
                                                   relief=SUNKEN,
                                                   bd=1)
        self.__buttonBox = self.createcomponent('buttonbox', (), None,
                                                Pmw.ButtonBox,
                                                (self.__commandFrame,),
                                                padx=0, pady=0)
        self.__buttonBox.pack(side=TOP, expand=NO, fill=X)
        if self['usecommandarea']:
            self.__commandFrame.pack(side=TOP,
                                     expand=NO,
                                     fill=X,
                                     padx=self['padx'],
                                     pady=self['pady'])


    def __createMessageBar(self):
        #The message bar start
        frame = self.createcomponent('bottomtray', (), None,
                                     Frame,(self._hull,), relief=SUNKEN)
        #Lotz the message bar
        # Create the message bar area for help and status messages.
        # Riht side Bada write
        self.__messageBar = self.createcomponent('messagebar',
                                                  (), None,
                                                 Pmw.MessageBar,
                                                 (frame,),
                                                 entry_width = 30,
                                                 entry_relief=SUNKEN,
                                                 entry_bd=1,
                                                 labelpos=W,
                                                 label_text='Help:')
        self.__messageBar.pack(side=RIGHT, expand=NO, fill=X)

        frame.pack(side=BOTTOM, expand=NO, fill=X)
        self.__balloon.configure(statuscommand = \
                                 self.__messageBar.helpmessage)


    def messageBar(self):
	return self.__messageBar

    def updateProgress(self, newValue=0, newMax=0):
        self.__progressBar.updateProgress(newValue, newMax)

    def bind(self, child, balloonHelpMsg, statusHelpMsg=None):
        # Bind a help message and/or status message to a widget.
        self.__balloon.bind(child, balloonHelpMsg, statusHelpMsg)

    def interior(self):
        # Retrieve the interior site where widgets should go.
        return self.dataArea

    def buttonBox(self):
        # Retrieve the button box.
        return self.__buttonBox

    def buttonAdd(self, buttonName, helpMessage=None,
                  statusMessage=None, **kw):
        # Add a button to the button box.
        newBtn = self.__buttonBox.add(buttonName)
        newBtn.configure(kw)
        if helpMessage:
             self.bind(newBtn, helpMessage, statusMessage)
        return newBtn
    #def curpos(self,event):
    #    global x, y, item
    #    x = event.x  
    #E    y = event.y
    #    item =self.imageDisplay.find_closest(x,y)  
    #    print item
    #def movemap(self,event):
    #    global x, y
    #    nx = event.x
    #    ny = event.y
    #    distx = nx - y
    #    disty = ny - x
    #    print  disty
    #    self.imageDisplay.move(item,distx, disty)
    #    x = nx
    #    y = ny

    
    def __createInterface(self):
        self.__createBalloon()
        self.__createMenuBar()
        self.__createDataArea()
        self.__createCommandArea()
        self.__createMessageBar()
        self.__createAboutBox()
	self.__createSideButten()
	self.__createSetting()
        #
        # Create the parts of the interface
        # which can be modified by subclasses
        #
        self.busyWidgets = ( self.root, )
        self.createMenuBar()
        self.createInterface()

    def createInterface(self):
        # Override this method to create the interface for the app.
        pass
        
    def main(self):
        # This method should be left intact!
        self.pack()
        self.mainloop()
        
    def run(self):
        self.main()

class TestAppShell(AppShell):
        usecommandarea=1
        
        def createButtons(self):
                self.buttonAdd('Ok',
                        helpMessage='Exit',
                        statusMessage='Exit',
                        command=self.quit)
                self.buttonAdd('Save',
                        helpMessage='Temper bada create',
                        statusMessage='test tempter bada ',
                        command=self.quit)
        
       
        
        def createMain(self):

                self.imageDisplay = self.createcomponent('imageLable',(), None,
                                        Canvas, self.interior(),
                                        width=AppShell.frameWidth-20 ,
                                        height=AppShell.frameHeight-20,
                                        borderwidth=0,
                                        relief=SOLID)
                                         
                self.ImageFile =  ImageTk.PhotoImage(file='./map1.jpg')
                self.imageDisplay.create_image(0, 0, image = self.ImageFile, anchor=NW,tags='map')
                self.imageDisplay.place(relx=0, rely=0)

                self.imageDisplay.create_oval(30, 30, 40, 40, width=1, fill="red",tags='oval')
                print "%d ,%d" % (self.imageDisplay.winfo_pointerxy())
                #self.imageDisplay.bind("<Button-1>", self.curpos)
                #self.imageDisplay.bind("<B1-Motion>", self.movemap)
    

                
                
                #print self.imageDisplay.place_info()
                #self.imageDisplay.pack()
                #print self.imageDisplay
                #self.bind(self.label, 'Space taker')
        	#for lattr in ['Format', 'Size', 'Mode']:
                #self.n = ""
                #print '%s:%s' % ( getattr(self.ImageFile, '%s' % string.lower(self.n)))
		    
                
        def createInterface(self):
                AppShell.createInterface(self)
                self.createButtons()
                self.createMain()
        
if __name__ == '__main__':
        test = TestAppShell(balloon_state='both')
        test.run()
